package com.chinaitop.depot.intelligent.IntelligentDetection.model;

import java.util.Date;

public class TTimingTask {
    private String tId;

    private String orgId;

    private String tName;

    private String vCfCode;

    private String tState;

    private String tUpdatePerson;

    private Date tUpdateTime;

    private String tDetectionDesc;

    private String tDetectionCron;

    private String tSwitch;

    private String tCategory;

    /**
     * 定时任务id
     * @return t_id 定时任务id
     */
    public String gettId() {
        return tId;
    }

    /**
     * 定时任务id
     * @param tId 定时任务id
     */
    public void settId(String tId) {
        this.tId = tId == null ? null : tId.trim();
    }

    /**
     * 
     * @return org_id 
     */
    public String getOrgId() {
        return orgId;
    }

    /**
     * 
     * @param orgId 
     */
    public void setOrgId(String orgId) {
        this.orgId = orgId == null ? null : orgId.trim();
    }

    /**
     * 任务名称
     * @return t_name 任务名称
     */
    public String gettName() {
        return tName;
    }

    /**
     * 任务名称
     * @param tName 任务名称
     */
    public void settName(String tName) {
        this.tName = tName == null ? null : tName.trim();
    }

    /**
     * 仓房编码
     * @return v_cf_code 仓房编码
     */
    public String getvCfCode() {
        return vCfCode;
    }

    /**
     * 仓房编码
     * @param vCfCode 仓房编码
     */
    public void setvCfCode(String vCfCode) {
        this.vCfCode = vCfCode == null ? null : vCfCode.trim();
    }

    /**
     * 是否执行(0是 1否)
     * @return t_state 是否执行(0是 1否)
     */
    public String gettState() {
        return tState;
    }

    /**
     * 是否执行(0是 1否)
     * @param tState 是否执行(0是 1否)
     */
    public void settState(String tState) {
        this.tState = tState == null ? null : tState.trim();
    }

    /**
     * 创建人
     * @return t_update_person 创建人
     */
    public String gettUpdatePerson() {
        return tUpdatePerson;
    }

    /**
     * 创建人
     * @param tUpdatePerson 创建人
     */
    public void settUpdatePerson(String tUpdatePerson) {
        this.tUpdatePerson = tUpdatePerson == null ? null : tUpdatePerson.trim();
    }

    /**
     * 创建时间
     * @return t_update_time 创建时间
     */
    public Date gettUpdateTime() {
        return tUpdateTime;
    }

    /**
     * 创建时间
     * @param tUpdateTime 创建时间
     */
    public void settUpdateTime(Date tUpdateTime) {
        this.tUpdateTime = tUpdateTime;
    }

    /**
     * 计划检测时间描述
     * @return t_detection_desc 计划检测时间描述
     */
    public String gettDetectionDesc() {
        return tDetectionDesc;
    }

    /**
     * 计划检测时间描述
     * @param tDetectionDesc 计划检测时间描述
     */
    public void settDetectionDesc(String tDetectionDesc) {
        this.tDetectionDesc = tDetectionDesc == null ? null : tDetectionDesc.trim();
    }

    /**
     * cron表达式
     * @return t_detection_cron cron表达式
     */
    public String gettDetectionCron() {
        return tDetectionCron;
    }

    /**
     * cron表达式
     * @param tDetectionCron cron表达式
     */
    public void settDetectionCron(String tDetectionCron) {
        this.tDetectionCron = tDetectionCron == null ? null : tDetectionCron.trim();
    }

    /**
     * 开关 (0:已关闭, 1:已开启)对应显示反转
     * @return t_switch 开关 (0:已关闭, 1:已开启)对应显示反转
     */
    public String gettSwitch() {
        return tSwitch;
    }

    /**
     * 开关 (0:已关闭, 1:已开启)对应显示反转
     * @param tSwitch 开关 (0:已关闭, 1:已开启)对应显示反转
     */
    public void settSwitch(String tSwitch) {
        this.tSwitch = tSwitch == null ? null : tSwitch.trim();
    }

    /**
     * 0粮温，1虫害，2气体，3能耗，4数量
     * @return t_category 0粮温，1虫害，2气体，3能耗，4数量
     */
    public String gettCategory() {
        return tCategory;
    }

    /**
     * 0粮温，1虫害，2气体，3能耗，4数量
     * @param tCategory 0粮温，1虫害，2气体，3能耗，4数量
     */
    public void settCategory(String tCategory) {
        this.tCategory = tCategory == null ? null : tCategory.trim();
    }
}